# viz

Visualization functions for matplotlib: plot ranges, streamgraphs, log-fitting,
polar grids, complex number plotting, and more.

## Example output

::::{grid} 1 2 2 3
:gutter: 3

:::{grid-item-card} plot_range
```{image} ../images/Figure_2_plot_range.png
:alt: plot_range example
```
:::

:::{grid-item-card} plot_diag
```{image} ../images/Figure_3_plot_diag.png
:alt: plot_diag example
```
:::

:::{grid-item-card} streamgraph
```{image} ../images/Figure_4_streamgraph.png
:alt: streamgraph example
```
:::

:::{grid-item-card} plot_cdf
```{image} ../images/Figure_5_plot_cdf.png
:alt: plot_cdf example
```
:::

:::{grid-item-card} plot_range_idx
```{image} ../images/Figure_7_plot_range_idx.png
:alt: plot_range_idx example
```
:::

:::{grid-item-card} plot_zero
```{image} ../images/Figure_8_plot_zero.png
:alt: plot_zero example
```
:::

:::{grid-item-card} subplotter
```{image} ../images/Figure_9_subplotter.png
:alt: subplotter example
```
:::

:::{grid-item-card} cplot
```{image} ../images/Figure_11_cplot.png
:alt: cplot example
```
:::
::::

## API reference

```{eval-rst}
.. automodule:: matviz.viz
   :members:
   :show-inheritance:
```
